"use client";
import { useState } from "react";

import PageHeader from "../../components/page-header";
import StoreCard from "../../components/store-card";
import { Button } from "@/components/ui/button";
import { Star, ShoppingCart, ShoppingBag } from "lucide-react";
import Image from "next/image";
import DownloadAppCard from "@/app/components/DownloadAppCard";
import { ReviewDes } from "@/app/products/review-des";
import {
  Accordion,
  AccordionItem,
  AccordionTrigger,
  AccordionContent,
} from "@/components/ui/accordion";
export default function page() {
  const [quantity, setQuantity] = useState(1);
  const products = [
    {
      image: "/assets/product-test-img/image 1.png",
      name: "Seeds Of Change Organic Quinoa, Brown",
      quantity: 1,
      link: "/product/1",
    },
    {
      image: "/assets/product-test-img/image 1.png",
      name: "Seeds Of Change Organic Quinoa, Yellow",
      quantity: 1,
      link: "/product/2",
    },
    {
      image: "/assets/product-test-img/image 1.png",
      name: "Seeds Of Change Organic Quinoa, Red",
      quantity: 1,
      link: "/product/3",
    },
    {
      image: "/assets/product-test-img/image 1.png",
      name: "Seeds Of Change Organic Quinoa, Mixed",
      quantity: 1,
      link: "/product/4",
    },
  ];
  return (
    <>
      <PageHeader title="Shop" breadcrumb="Home - Product" />

      <div className="mx-auto w-full p-4 max-w-6xl">
        <div className="flex flex-col md:flex-row gap-6">
          {/* Product Image */}
          <div className="w-full md:w-[40%]">
            <Image
              src="/assets/product-test-img/image 1.png"
              alt="Product"
              width={400}
              height={400}
              className="rounded-lg object-contain bg-black  w-full h-auto"
            />
          </div>

          {/* Product Details */}
          <div className="w-full md:w-[45%]">
            <h1 className="text-xl">Seeds Of Change Organic Quinoa, Brown</h1>
            <p className="text-customGrayBlack text-sm mt-2">
              Lorem ipsum dolor sit amet consectetur adipisicing elit.
            </p>

            <div className="flex items-center space-x-2 mt-2">
              <Star size={15} className="text-yellow-500 fill-current" />
              <Star size={15} className="text-yellow-500 fill-current" />
              <Star size={15} className="text-yellow-500 fill-current" />
              <Star size={15} className="text-yellow-500 fill-current" />
              <span className="text-custom15 text-customGrayBlack">
                (7 Reviews)
              </span>
            </div>
            <div>
              <h2 className="text-customGrayBlack text-custom16 mt-3">
                Brand:
                <span className="text-black font-custom500 ml1">
                  Brand Name Here
                </span>
              </h2>
            </div>

            <div className="mt-4">
              <span className="text-lg font-bold text-red-500">Rs. 120.25</span>
            </div>
            <div className="mt-1">
              <span className="text-gray-500 line-through">Rs. 150.25</span>
              <span className="text-black ml-2">-35%</span>
            </div>

            <div className="mt-5 flex gap-4">
              <div>
                <h3 className="text-custom16 font-custom500 w-28">Quantity:</h3>
              </div>
              <div className="space-x-3">
                <Button
                  variant="outline"
                  onClick={() => setQuantity((prev) => Math.max(1, prev - 1))}
                  className="text-customGrayBlack text-xs px-2 h-6  border border-grayBlack rounded-sm"
                >
                  -
                </Button>
                <span className="  rounded-md text-xs font-semibold">
                  {quantity}
                </span>
                <Button
                  variant="outline"
                  onClick={() => setQuantity((prev) => prev + 1)}
                  className="text-customGrayBlack text-xs px-2 h-6  border border-grayBlack rounded-sm"
                >
                  +
                </Button>
              </div>
            </div>

            <div className="mt-10 gap-6 flex ">
              <button className="bg-foreground  text-sm py-2 px-2   text-white font-semibold rounded-sm flex gap-1 w-1/2 justify-center">
                <ShoppingBag size={16} /> Buy Now
              </button>
              <button className="bg-primary  text-sm  py-2 px-2 text-white font-semibold rounded-sm  flex gap-1 w-1/2 justify-center">
                <ShoppingCart size={16} /> Add to Cart
              </button>
            </div>
          </div>

          {/* Store Image */}
          <div className="w-full md:w-[14%] flex justify-center md:justify-end">
            <Image
              className="w-full rounded-md object-contain"
              src="/assets/product-test-img/store.png"
              alt="Store"
              width={250}
              height={400}
            />
          </div>
        </div>
        <div className="mt-5">
          <Accordion type="single" collapsible defaultValue="products">
            <AccordionItem value="products" className="border rounded-lg p-4">
              <AccordionTrigger>Products Included</AccordionTrigger>
              <AccordionContent>
                <div className="mt-2">
                  {products.map((product, index) => (
                    <div
                      key={index}
                      className="flex items-center justify-between gap-4 border-b py-2"
                    >
                      <div className="flex gap-2 items-center md:w-[60%]">
                        <img
                          src={product.image}
                          alt={product.name}
                          className="w-12 h-12 rounded"
                        />
                        <h2 className="text-customGrayBlack font-medium">
                          {product.name}
                        </h2>
                      </div>

                      <h2 className="text-black text-sm">
                        {" "}
                        Quantity: {product.quantity}
                      </h2>
                      <button
                        href={product.link}
                        className="text-blue-500 text-sm"
                      >
                        View
                      </button>
                    </div>
                  ))}
                </div>
              </AccordionContent>
            </AccordionItem>
          </Accordion>
        </div>

        <div className="mt-5 flex gap-4">
          <StoreCard />
          <DownloadAppCard />
        </div>
        <div className="mt-5 w-full">
          <ReviewDes />
        </div>
      </div>
    </>
  );
}
